@@ -5,9 +5,8 @@ Created on Wed Apr 29 15:07:55 2020
 
 @author: mike
 """
-# import os
-# import selenium
-# import datetime
+import os
+import random
 import pandas as pd
 import numpy as np
 from selenium import webdriver
@@ -235,12 +234,15 @@ class Cliflo(object):
         """
 
         """
+        # if hasattr(self, 'driver'):
+        #     self.driver.quit()
+
         options = webdriver.ChromeOptions()
         options.add_argument("headless")
         driver = webdriver.Chrome(self.chromedriver, options=options)
 
         ### Open main Cliflo site for login
-        driver.get('https://cliflo.niwa.co.nz')
+        driver.get('https://cliflo.niwa.co.nz/pls/niwp/wa.logindb?cDyn=true')
 
         ### Log in
         user_box = driver.find_element_by_name('cusername')
@@ -254,7 +256,9 @@ class Cliflo(object):
         submit_box = driver.find_element_by_name('submit')
         submit_box.click()
 
-        sleep(6)
+        sleep(2)
+
+        driver.switch_to.window(driver.window_handles[1])
 
         self.driver = driver
         print('logged in')
@@ -397,3 +401,138 @@ class Cliflo(object):
         name = c3[:c3.find('<')]
 
         return name
+
+    @staticmethod
+    def new_subscription(chrome_driver_path):
+        """
+
+        """
+        # ### Open headless Chrome driver
+        # if hasattr(self, 'driver'):
+        #     driver = self.driver
+        # else:
+        #     raise ValueError('You must be logged in to get ts data')
+
+        ## Open driver
+        options = webdriver.ChromeOptions()
+        options.add_argument("headless")
+        driver = webdriver.Chrome(chrome_driver_path, options=options)
+
+        ## Open main Cliflo site for login
+        driver.get('https://cliflo.niwa.co.nz/pls/niwp/wsubform.intro')
+
+        # driver.switch_to.window(driver.window_handles[0])
+
+        ## Generate username
+        username = generate_username()[0]
+
+        ## Click through
+        cont_box = driver.find_element_by_xpath('//input[@value="Continue to Username"]')
+        cont_box.click()
+
+        user_box = driver.find_element_by_name('username')
+        user_box.clear()
+        user_box.send_keys(str(username))
+
+        submit_box = driver.find_element_by_name('go_to_client')
+        submit_box.click()
+
+        user_box = driver.find_element_by_name('cfull_name')
+        user_box.clear()
+        user_box.send_keys('Bob Smith')
+
+        user_box = driver.find_element_by_name('corganisation')
+        user_box.clear()
+        user_box.send_keys('Smith Inc.')
+
+        user_box = driver.find_element_by_name('cemail1')
+        user_box.clear()
+        user_box.send_keys('smith111@gmail.com')
+
+        user_box = driver.find_element_by_name('cemail2')
+        user_box.clear()
+        user_box.send_keys('smith111@gmail.com')
+
+        user_box = driver.find_element_by_name('cpostal_address')
+        user_box.clear()
+        user_box.send_keys('123 Smith Street, Christchurch 8011, NZ')
+
+        user_box = driver.find_element_by_name('ccity')
+        user_box.clear()
+        user_box.send_keys('Christchurch')
+
+        submit_box = driver.find_element_by_name('sub_purpose')
+        submit_box.click()
+
+        driver.switch_to.window(driver.window_handles[1])
+
+        org_box = driver.find_element_by_xpath('//option[@value="government_-_local/regional/state"]')
+        org_box.click()
+
+        org_box = driver.find_element_by_name('env1')
+        org_box.click()
+
+        submit_box = driver.find_element_by_name('sub_review')
+        submit_box.click()
+
+        submit_box = driver.find_element_by_name('sub_terms')
+        submit_box.click()
+
+        agree_box = driver.find_element_by_name('agree')
+        agree_box.click()
+
+        page = driver.page_source
+
+        index1 = page.find('Your temporary password is:')
+        page1 = page[(index1 + 31):]
+        index2 = page1.find('</b>')
+
+        password = page1[:index2]
+
+        driver.quit()
+
+        return username, password
+
+
+
+
+
+
+def generate_username(num_results=1):
+    directory_path = os.path.dirname(__file__)
+    adjectives, nouns = [], []
+    with open(os.path.join(directory_path, 'data', 'adjectives.txt'), 'r') as file_adjective:
+        with open(os.path.join(directory_path, 'data', 'nouns.txt'), 'r') as file_noun:
+            for line in file_adjective:
+                adjectives.append(line.strip())
+            for line in file_noun:
+                nouns.append(line.strip())
+
+    usernames = []
+    for _ in range(num_results):
+        adjective = random.choice(adjectives)
+        noun = random.choice(nouns)
+        num = str(random.randrange(1000))
+        usernames.append(adjective + noun + num)
+
+    return usernames
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
